#
# spec file for package python-django-cacheops
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-cacheops
Version:        7.2
Release:        1.1
Summary:        Django ORM cache with automatic granular event-driven invalidation
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://github.com/Suor/django-cacheops
Source:         https://files.pythonhosted.org/packages/source/d/django_cacheops/django_cacheops-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 3.2
Requires:       python-funcy >= 1.8
Requires:       python-redis >= 3.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Django >= 3.2}
BuildRequires:  %{python_module before-after}
BuildRequires:  %{python_module dill}
BuildRequires:  %{python_module funcy >= 1.8}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module redis >= 3.0.0}
BuildRequires:  redis
# /SECTION
%python_subpackages

%description
A slick app that supports automatic or manual queryset caching and automatic
granular event-driven invalidation.

It uses `redis <http://redis.io/>`_ as backend for ORM cache and redis or
filesystem for simple time-invalidated one.

%prep
%autosetup -p1 -n django_cacheops-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
/usr/sbin/redis-server &
export DJANGO_SETTINGS_MODULE=tests.settings
%pytest

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%{python_sitelib}/cacheops
%{python_sitelib}/django_cacheops-%{version}*-info

%changelog
* Tue Apr 22 2025 Markéta Machová <mmachova@suse.com>
- update to 7.2
  * support and test against Python 3.13 and Django 5.1/5.2
  * updated md5 to set usedforsecurity for FIPS compliance
  * skip ArrayField in exact conds
* Thu Nov  7 2024 Markéta Machová <mmachova@suse.com>
- update to 7.1
  * support and test against Python 3.12 and Django 5.0
  * prevent dups in conjs and disjs by using proper data-structures
  * unpin funcy major version
  * fixed conj keys TTL in Redis 7.x
  * updated and cleaned up tests
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 7.0.2:
  * fixed .aggregate()
  * fixed big memory usage during migrations
  * fixed INSIDEOUT in older redises
  * better handle model families with abstracts in them
  * allow funcy 2.0+
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 7.0.1:
  * made it work with Redis 6.x and older again
  * handle abstract models better
  * some docs improvements
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 7.0:
  * support Django 4.2b and 5.0a
  * added a new insideout mode made join invalidation more granular
  * dropped Python 3.5, 3.6 and Django 2.1, 2.2, 3.0 and 3.1
    support
  * removed CACHEOPS_LRU
  * support Python 3.11 and Django 4.1
  * added command to clear stale cacheops keys (Bruno Alla)
  * fixed `invalidate_m2o` for polymorphic models
  * updated README: TOC, link to the post, some explanations
* Tue Nov 22 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six dependency
- Remove python_module macro definition
- More specific python_sitelib in %%files
* Thu Aug 25 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v6.1
  * support Django 3.2 and 4.0
  * do not gulp commit errors
  * fixed precall key when a prefix is defined
  * fixed m2o/m2m queries invalidation on object deletion
* Wed Apr 20 2022 Markéta Machová <mmachova@suse.com>
- do not require mock
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun May  9 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to v6.0
  * support and test against Python 3.9 and Django 3.1/3.2
  * added custom serializers support (thx to Arcady Usov)
  * support callable extra in @cached_as() and friends
  * made simple cache obey prefix
  * skip JSONFields for purposes of invalidation
  * configure skipped fields by internal types, classes still supported
  * handle `DatabaseError` on transaction cleanup (Roman Gorbil)
  * do not query old object if cacheops is disabled
  * do not fetch deferred fields during invalidation, fixes #387
  Backwards incompatible changes:
  * callable `extra` param, including type, now behaves differently
  * simple cache now uses prefix
* Mon Oct 26 2020 John Vandenberg <jayvdb@gmail.com>
- Switch to PyPI source
- Update to v5.1
  * support subqueries in annotations
  * included tests into distro
  * fixed .invalidated_update(), if updated QuerySet had related
    fields selected
  * fixed possible deadlock in .invalidated_update()
  * fixed filtering with expressions
  * fixed queries filtering in Exists
  * updated min redis-py to 3.0.0
* Mon Sep  7 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Thu Aug 27 2020 Daniel Molkentin <daniel.molkentin@suse.com>
- update to v5.0.1
  * fixed reverse o2o invalidation (thx to John Anderson)
  * fixed unstable cache key when field validors are used
  * guard against non-integer timeouts
- from v5.0
  * dropped Python 2.7 and Djangos before 2.1
  * Redis 4.0+ required
  * support Python 3.8 and Django 3.0 (thx to Misha Kalyna)
  * improve model fields stamping (Alex Lokhman)
  * disabled postponed invalidation when no_invalidation is applied (Vladimir)
  * fixed custom manager derived from BaseManager (Eric Plaster)
* Thu Nov 21 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 4.2
* Sat Sep 28 2019 ecsos@opensuse.org
- Fix requirements.
* Thu Aug 29 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Initial checkin
